@@ -11,7 +11,7 @@ Pandoc - wrapper for the mighty Pandoc document converter
 
 =cut
 
-our $VERSION = '0.7.2';
+our $VERSION = '0.8.0';
 
 use Pandoc::Version;
 use Carp 'croak';
@@ -46,7 +46,13 @@ sub new {
     my $pandoc = bless { }, shift;
 
     my $bin = (@_ and $_[0] !~ /^-./) ? shift : $PANDOC_PATH;
-    $pandoc->{bin} = which($bin);
+
+    my $bindir = $ENV{HOME}."/.pandoc/bin";
+    if (!-x $bin && $bin =~ /^\d+(\.\d+)*$/ && -x "$bindir/pandoc-$bin") {
+        $pandoc->{bin} = "$bindir/pandoc-$bin";
+    } else {
+        $pandoc->{bin} = which($bin);
+    }
 
     $pandoc->{arguments} = [];
     $pandoc->arguments(@_) if @_;
@@ -268,6 +274,33 @@ sub highlight_languages {
     $_[0]->_list('highlight_languages');
 }
 
+sub extensions {
+    my $pandoc = shift;
+    my $format = shift // '';
+    my $out = "";
+    my %ext;
+
+    if ($pandoc->version < 1.18) {
+        warn "pandoc >= 1.18 required for --list-extensions\n";
+    } else {
+        if ($format) {
+            if ($format =~ /^[a-z0-9_]$/ and $pandoc->version >= '2.0.6') {
+                $format = "=$format";
+            } else {
+                warn "ignoring format argument to Pandoc->extensions\n";
+                $format = '';
+            }
+        }
+        $pandoc->run("--list-extensions$format", { out => \$out });
+        %ext = map {
+          $_ =~ /^([+-]?)\s*([^-+ ]+)\s*([+-]?)$/;
+          ($2 => ($1 || $3) eq '+' ? 1 : 0);
+        } split /\n/, $out;
+    }
+
+    %ext;
+}
+
 sub libs {
     $_[0]->{libs};
 }
@@ -319,12 +352,15 @@ __END__
   my $md2latex = Pandoc->new(qw(-f markdown -t latex --number-sections));
   $md2latex->run({ in => \$markdown, out => \$latex });
 
+  # create a new instance with selected executable
+  my $pandoc = Pandoc->new('bin/pandoc');
+  my $pandoc = Pandoc->new('2.1'); # use ~/.pandoc/bin/pandoc-2.1 if available
+
   # set default arguments on compile time
   use Pandoc qw(-t latex);
   use Pandoc qw(/usr/bin/pandoc --number-sections);
   use Pandoc qw(1.16 --number-sections);
 
-
   # utility method to convert from string
   $latex = pandoc->convert( 'markdown' => 'latex', '*hello*' );
 
@@ -416,12 +452,14 @@ references.
 
 =head1 METHODS
 
-=head2 new( [ $executable ] [, @arguments ] )
+=head2 new( [ $executable | $version ] [, @arguments ] )
 
 Create a new instance of class Pandoc or throw an exception if no pandoc
-executable was found. The first argument, if given and not starting with C<->,
-can be used to set the pandoc executable (C<pandoc> by default). Additional
-arguments are passed to the executable on each run.
+executable was found.  The first argument, if given and not starting with C<->,
+can be used to set the pandoc executable (C<pandoc> by default).  If a version
+is specified the executable is also searched in C<~/.pandoc/bin>, e.g.
+C<~/.pandoc/bin/pandoc-2.0> for version C<2.0>.  Additional arguments are
+passed to the executable on each run.
 
 Repeated use of this constructor with same arguments is not recommended because
 C<pandoc --version> is called for every new instance.
@@ -505,6 +543,12 @@ Return a list of supported output formats.
 Return a list of programming languages which syntax highlighting is supported
 for (via Haskell library highlighting-kate).
 
+=head2 extensions( [ $format ] )
+
+Return a hash of extensions mapped to whether they are enabled by default.
+This method is only available since Pandoc 1.18 and the optional format
+argument since Pandoc 2.0.6.
+
 =head2 libs
 
 Return a hash mapping the names of Haskell libraries compiled into the
